.. Copyright (C) 2015-2017 Robin Schneider <ypid@riseup.net>
.. Copyright (C) 2017 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

.. _martin-v.sshpreluks: https://github.com/martin-v/ansible-sshpreluks
.. _systemli.rootcrypto: https://github.com/systemli/ansible-rootcrypto
.. _FDEunlock: https://gitlab.com/ypid/fdeunlock
